@@ -8,45 +8,51 @@ import cloudlanguagetools.languages
 import cloudlanguagetools.errors
 import cloudlanguagetools.azure
 import cloudlanguagetools.google
-import cloudlanguagetools.mandarincantonese
-import cloudlanguagetools.easypronunciation
 import cloudlanguagetools.watson
 import cloudlanguagetools.naver
 import cloudlanguagetools.amazon
 import cloudlanguagetools.forvo
 import cloudlanguagetools.cereproc
-import cloudlanguagetools.epitran
-import cloudlanguagetools.deepl
 import cloudlanguagetools.vocalware
 import cloudlanguagetools.fptai
 import cloudlanguagetools.voicen
-import cloudlanguagetools.pythainlp
-import cloudlanguagetools.spacy
-import cloudlanguagetools.argostranslate
-import cloudlanguagetools.wenlin
 import cloudlanguagetools.encryption
 
+LOAD_NLP_MODELS = os.environ.get('CLOUDLANGUAGETOOLS_CORE_LOAD_NLP', 'yes') == 'yes'
+
+if LOAD_NLP_MODELS:
+    import cloudlanguagetools.deepl
+    import cloudlanguagetools.epitran
+    import cloudlanguagetools.mandarincantonese
+    import cloudlanguagetools.easypronunciation
+    import cloudlanguagetools.pythainlp
+    import cloudlanguagetools.spacy
+    import cloudlanguagetools.argostranslate
+    import cloudlanguagetools.wenlin
+
 class ServiceManager():
     def  __init__(self):
         self.services = {}
         self.services[cloudlanguagetools.constants.Service.Azure.name] = cloudlanguagetools.azure.AzureService()
         self.services[cloudlanguagetools.constants.Service.Google.name] = cloudlanguagetools.google.GoogleService()
-        self.services[cloudlanguagetools.constants.Service.EasyPronunciation.name] = cloudlanguagetools.easypronunciation.EasyPronunciationService()
         self.services[cloudlanguagetools.constants.Service.Watson.name] = cloudlanguagetools.watson.WatsonService()
         self.services[cloudlanguagetools.constants.Service.Naver.name] = cloudlanguagetools.naver.NaverService()
         self.services[cloudlanguagetools.constants.Service.Amazon.name] = cloudlanguagetools.amazon.AmazonService()
         self.services[cloudlanguagetools.constants.Service.Forvo.name] = cloudlanguagetools.forvo.ForvoService()
         self.services[cloudlanguagetools.constants.Service.CereProc.name] = cloudlanguagetools.cereproc.CereProcService()
-        self.services[cloudlanguagetools.constants.Service.Epitran.name] = cloudlanguagetools.epitran.EpitranService()
-        self.services[cloudlanguagetools.constants.Service.DeepL.name] = cloudlanguagetools.deepl.DeepLService()
         self.services[cloudlanguagetools.constants.Service.VocalWare.name] = cloudlanguagetools.vocalware.VocalWareService()
         self.services[cloudlanguagetools.constants.Service.FptAi.name] = cloudlanguagetools.fptai.FptAiService()
         self.services[cloudlanguagetools.constants.Service.Voicen.name] = cloudlanguagetools.voicen.VoicenService()
-        self.services[cloudlanguagetools.constants.Service.PyThaiNLP.name] = cloudlanguagetools.pythainlp.PyThaiNLPService()
-        self.services[cloudlanguagetools.constants.Service.Spacy.name] = cloudlanguagetools.spacy.SpacyService()
-        self.services[cloudlanguagetools.constants.Service.MandarinCantonese.name] = cloudlanguagetools.mandarincantonese.MandarinCantoneseService()            
-        self.services[cloudlanguagetools.constants.Service.ArgosTranslate.name] = cloudlanguagetools.argostranslate.ArgosTranslateService()
-        self.services[cloudlanguagetools.constants.Service.Wenlin.name] = cloudlanguagetools.wenlin.WenlinService()
+
+        if LOAD_NLP_MODELS:
+            self.services[cloudlanguagetools.constants.Service.EasyPronunciation.name] = cloudlanguagetools.easypronunciation.EasyPronunciationService()
+            self.services[cloudlanguagetools.constants.Service.Epitran.name] = cloudlanguagetools.epitran.EpitranService()
+            self.services[cloudlanguagetools.constants.Service.DeepL.name] = cloudlanguagetools.deepl.DeepLService()
+            self.services[cloudlanguagetools.constants.Service.PyThaiNLP.name] = cloudlanguagetools.pythainlp.PyThaiNLPService()
+            self.services[cloudlanguagetools.constants.Service.Spacy.name] = cloudlanguagetools.spacy.SpacyService()
+            self.services[cloudlanguagetools.constants.Service.MandarinCantonese.name] = cloudlanguagetools.mandarincantonese.MandarinCantoneseService()            
+            self.services[cloudlanguagetools.constants.Service.ArgosTranslate.name] = cloudlanguagetools.argostranslate.ArgosTranslateService()
+            self.services[cloudlanguagetools.constants.Service.Wenlin.name] = cloudlanguagetools.wenlin.WenlinService()
 
     def configure_default(self):
         # use the stored keys to configure services
@@ -54,7 +60,8 @@ class ServiceManager():
 
     def configure_services(self, config):
         for service_name, value in config.items():
-            self.services[service_name].configure(value)
+            if service_name in self.services:
+                self.services[service_name].configure(value)
 
     def get_language_data_json(self):
         # retrieve all language data (tts, translation, transliteration, etc)
